import { type ZodSchema, type infer as Infer } from 'zod';
import { type TypeResponse } from '../Type/Response.js';
import { type ActionInterface } from '../Interface/ActionInterface.js';
export declare class ZodSchemaValidatedAction<TypePayloadSchema extends ZodSchema, TypeObjectSchema extends ZodSchema> implements ActionInterface<Infer<TypePayloadSchema>, Infer<TypeObjectSchema>> {
    private readonly payloadSchema;
    private readonly objectSchema;
    private readonly action;
    /**
     * Constructor.
     *
     * @param {TypePayloadSchema} payloadSchema - The Zod schema for the input data
     * @param {TypeObjectSchema} objectSchema - The Zod schema for the output data
     * @param {ActionInterface<Infer<TypePayloadSchema>, Infer<TypeObjectSchema>>} action - The action to wrap
     */
    constructor(payloadSchema: TypePayloadSchema, objectSchema: TypeObjectSchema, action: ActionInterface<Infer<TypePayloadSchema>, Infer<TypeObjectSchema>>);
    /**
     * Executes the action logic after validating the input payload and the response.
     *
     * @param {Infer<TypePayloadSchema>} payload - The input payload for the action
     * @returns {Promise<TypeResponse<Infer<TypeObjectSchema>>>} - The result of the action wrapped in a TypeResponse
     */
    execute(payload: Infer<TypePayloadSchema>): Promise<TypeResponse<Infer<TypeObjectSchema>>>;
}
