import { ZodSchema, type infer as Infer } from 'zod';
import { type ToolInterface } from '../Interface/ToolInterface.js';
import { ZodSchemaValidatedAction } from '../Action/ZodSchemaValidatedAction.js';
import { type ActionInterface } from '../Interface/ActionInterface.js';
/**
 * ActionTool is a specialized class that will use a given action as a tool.
 */
export declare class ActionTool<TypePayloadSchema extends ZodSchema, TypeResponseSchema extends ZodSchema> extends ZodSchemaValidatedAction<TypePayloadSchema, TypeResponseSchema> implements ToolInterface<Infer<TypePayloadSchema>, Infer<TypeResponseSchema>> {
    readonly name: string;
    readonly description: string;
    readonly parameters: TypePayloadSchema;
    /**
     * Constructor.
     *
     * @param {string} name - The name of the tool
     * @param {string} description - The description of the tool
     * @param {TypePayloadSchema} payloadSchema - The Zod schema for the input data
     * @param {TypeResponseSchema} responseSchema - The Zod schema for the output data
     * @param {ActionInterface<Infer<TypePayloadSchema>, Infer<TypeResponseSchema>>} action - The action to wrap
     */
    constructor(name: string, description: string, payloadSchema: TypePayloadSchema, responseSchema: TypeResponseSchema, action: ActionInterface<Infer<TypePayloadSchema>, Infer<TypeResponseSchema>>);
}
